[Scummvm-cvs-logs] SF.net SVN: scummvm:[52068] scummvm/trunk/engines/sci/graphics/ports.cpp

m_kiewitz at users.sourceforge.net m_kiewitz at users.sourceforge.net
Fri Aug 13 20:25:16 CEST 2010


Revision: 52068
          http://scummvm.svn.sourceforge.net/scummvm/?rev=52068&view=rev
Author:   m_kiewitz
Date:     2010-08-13 18:25:16 +0000 (Fri, 13 Aug 2010)

Log Message:
-----------
SCI: extending life of port for sq4 gum wrapper

fixes bug #3044507

Modified Paths:
--------------
    scummvm/trunk/engines/sci/graphics/ports.cpp

Modified: scummvm/trunk/engines/sci/graphics/ports.cpp
===================================================================
--- scummvm/trunk/engines/sci/graphics/ports.cpp	2010-08-13 13:33:29 UTC (rev 52067)
+++ scummvm/trunk/engines/sci/graphics/ports.cpp	2010-08-13 18:25:16 UTC (rev 52068)
@@ -446,14 +446,15 @@
 		_paint16->kernelGraphRedrawBox(pWnd->restoreRect);
 	_windowList.remove(pWnd);
 	setPort(_windowList.back());
 	// We will actually free this window after 10 kSetPort-calls
 	// Sierra sci freed the pointer immediately, but pointer to that port
 	//  still worked till the memory got overwritten. Some games depend
 	//  on this (dispose a window and then kSetPort to it again for once)
 	//  Those are actually script bugs, but patching all of those out
 	//  would be quite a hassle and this just keeps compatibility
 	//  (examples: hoyle 4 game menu and sq4cd inventory)
-	pWnd->counterTillFree = 10;
+	//  sq4cd gum wrapper requires more than 10
+	pWnd->counterTillFree = 15;
 	_freeCounter++;
 }
 
@@ -446,14 +446,15 @@
 	_windowList.remove(pWnd);
 	setPort(_windowList.back());
-	// We will actually free this window after 10 kSetPort-calls
+	// We will actually free this window after 15 kSetPort-calls
 	// Sierra sci freed the pointer immediately, but pointer to that port
 	//  still worked till the memory got overwritten. Some games depend


This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.




More information about the Scummvm-git-logs mailing list